@@ -8,7 +8,7 @@
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-Version = '0.8-4'
+Version = '0.8-7'
 
 import os
 import sys
@@ -266,7 +266,7 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
          QtGui.QDialog.__init__(self, parent)
          self.ui = Ui_DialogStart()
          self.ui.setupUi(self)
-         ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
          ##Connect the button
@@ -311,7 +311,7 @@ class MyMainWindow(QtGui.QMainWindow):
           QtGui.QWidget.__init__(self, parent)
           self.ui = Ui_SMSCON_GUI_elements()
           self.ui.setupUi(self)
-          ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+          self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
           self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
           ##Connect the GUI Buttons with actions
@@ -905,7 +905,7 @@ class MyPasswordDialog(QtGui.QDialog):
          QtGui.QDialog.__init__(self, parent)
          self.ui = Ui_DialogPassword()
          self.ui.setupUi(self)
-         ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
           
          ##Connect the button
